--[[
 Holiday Companion module for MiniPet
 Version 5.1.242
 $Revision: 183 $

 All credit for authoring this addon is listed below
]]--

--[[
Copyright (c) 2011, LordFarlander
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

    * Redistributions of source code must retain the above copyright notice,
      this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright notice,
      this list of conditions and the following disclaimer in the documentation
      and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
]]--

local L = LibStub( "AceLocale-3.0" ):GetLocale( "MiniPet holiday Module" )

local PetAndMountDatabase = LibStub( "LibLordFarlander-PetAndMountDatabase-1.1", true )
if( not PetAndMountDatabase ) then
    return
end--if

if( not LibStub( "LibLordFarlander-Randomizer-2.0", true ) ) then
    return
end--if

local TR = LibStub( "LibLordFarlander-TableRecycler-1.0", true )
if( not TR ) then
    return
end--if

local moduleName = "Holiday"

local Holiday = {
    displayname = L["Holiday"],
    events = {
        "VerifyRandom",
    },
}

function Holiday.IsHolidayToday( holiday )
    local _, _, day, _ = CalendarGetDate()

    for i = 1, CalendarGetNumDayEvents( 0, day ) do
        local title, hour, minute, calendarType, sequenceType = CalendarGetDayEvent( 0, day, i )

        if( ( calendarType == "HOLIDAY" ) and ( title == holiday ) ) then
            local gameHour, gameMinute = GetGameTime()

            if( sequenceType == "START" ) then
                -- The holiday starts today, check if now is after the start
                return ( gameHour > hour ) or ( ( gameHour == hour ) and ( gameMinute >= minute ) )
            elseif( sequenceType == "END" ) then
                -- The holiday ends today, check if now is before the end
                return ( gameHour < hour ) or ( ( gameHour == hour ) and ( gameMinute < minute ) )
            else
                -- in the middle of the holiday, it's definitely on
                return true
            end--if
        end--if
    end--for
    -- The holiday wasn't found for today
    return false
end--Holiday.IsHolidayToday( holiday )

function Holiday:OnVerifyRandom( MiniPet, itemID )
    local holiday = PetAndMountDatabase:ItemInSet( itemID, "companion.Holiday" )
    local returnval = true

    if( holiday ) then
        local conditions = PetAndMountDatabase.GetConditions( holiday )

        if( conditions and conditions.Holiday ) then
            returnval = self.IsHolidayToday( L[conditions.Holiday] )
        end--if
        TR:ReturnTable( conditions )
    end--if
    return returnval
end--Holiday:OnVerifyRandom( MiniPet, itemID )

LibStub( "LibLordFarlander-Randomizer-2.0" ):RegisterModuleToHandler( "MiniPet", moduleName, Holiday, "Companions" )
